@@ -1,3 +1,4 @@
+# This file is managed by `git_helper`. Don't edit it directly
 # Copyright (C) 2019-2020 Dominic Davis-Foster <dominic@davis-foster.co.uk>
 #
 #  This program is free software: you can redistribute it and/or modify
@@ -21,10 +22,10 @@ copyright = """
 2019-2020 Dominic Davis-Foster <dominic@davis-foster.co.uk>
 """
 
-VERSION = "0.3.0"
+VERSION = "0.3.2"
 
 modname = "domdf_python_tools"
-py_modules = None
+py_modules = []
 entry_points = None
 
 license = 'LGPLv3+'
@@ -34,9 +35,9 @@ short_desc = 'Helpful functions for Python'
 author = "Dominic Davis-Foster"
 author_email = "dominic@davis-foster.co.uk"
 github_username = "domdfcoding"
-web = github_url = f"https://github.com/{github_username}/{modname}"
+web = github_url = f"https://github.com/domdfcoding/domdf_python_tools"
 project_urls = {
-		"Documentation": f"https://{modname}.readthedocs.io",  # TODO: Make this link match the package version
+		"Documentation": f"https://domdf_python_tools.readthedocs.io",  # TODO: Make this link match the package version
 		"Issue Tracker": f"{github_url}/issues",
 		"Source Code": github_url,
 		}
@@ -45,24 +46,27 @@ repo_root = pathlib.Path(__file__).parent
 
 # Get info from files; set: long_description
 long_description = (repo_root / "README.rst").read_text() + '\n'
+conda_description = """Helpful functions for Python
+
+
+Before installing please ensure you have added the following channels: domdfcoding, conda-forge"""
 install_requires = (repo_root / "requirements.txt").read_text().split('\n')
-extras_require = {"dates": ["pytz>=2019.1"]}
+extras_require = {'dates': ['pytz>=2019.1'], 'all': ['pytz>=2019.1']}
 
 classifiers = [
 		'Development Status :: 4 - Beta',
-		# "Development Status :: 4 - Beta",
-		# "Development Status :: 5 - Production/Stable",
-		# "Development Status :: 6 - Mature",
-		# "Development Status :: 7 - Inactive",
 		'Intended Audience :: Developers',
-		"License :: OSI Approved :: GNU Lesser General Public License v3 (LGPLv3)",
+		'License :: OSI Approved :: GNU Lesser General Public License v3 (LGPLv3)',
 		'Operating System :: OS Independent',
 		'Programming Language :: Python',
 		'Programming Language :: Python :: 3.6',
 		'Programming Language :: Python :: 3.7',
 		'Programming Language :: Python :: 3.8',
-		"Programming Language :: Python :: 3 :: Only",
-		"Programming Language :: Python :: Implementation :: CPython",
-		"Programming Language :: Python :: Implementation :: PyPy",
+		'Programming Language :: Python :: 3 :: Only',
+		'Programming Language :: Python :: Implementation :: CPython',
+		'Programming Language :: Python :: Implementation :: PyPy',
 		'Topic :: Software Development :: Libraries :: Python Modules',
+		
 		]
+
+keywords = ""
